import { http } from "./httpClient";

import { Consultant } from "~/shared/models/consultant.model";
import { FastQueryParams } from "~/shared/models/quick-filter.model";
import { AgentOfStrictQuery, StrictQueryParams } from "~/shared/models/strict-query.model";
import { AppointmentParams } from "~/shared/models/appointment.model";

class QueryConsultantService {

  // 推薦保險顧問
  async getRecommendConsultantList(): Promise<Consultant[]> {
    return http.get<Consultant[]>('/consultant/recommend').then((res) => res.data);
  }

  // 快速篩選
  async fastQuery(data: FastQueryParams): Promise<Consultant[]> {
    try {
      const response = await http.post<Consultant[]>('/consultant/fastQuery', data);
      if (response !== null) {
        return response.data;
      } else {
        throw new Error('http.post returned null-like value.');
      }
    } catch (error) {
      console.error('An error occurred while performing fast query:', error);
      // 可以在此處處理錯誤或回傳預設值
      throw error;
    }
  }


  // 嚴選配對
  async strictQuery(data:StrictQueryParams): Promise<AgentOfStrictQuery[]>{
    return http.post('/consultant/strictQuery', data).then((res) => res.data);
  }

  // 加入顧問
  async addFavoriteConsultant(addFavoriteConsultantList: AddFavoriteConsultantItem[]) {
    const payload = {
      consultantList: addFavoriteConsultantList
    };
    return http.post('/consultant/favorite', payload);
  }

  /**
   * 預約需求
   * @param data 包含預約需求相關資訊的物件
   * @returns 回傳預約需求結果
   */
  async  appointmentDemand(data: AppointmentParams) {
    try {
      const response = await http.post('/appointment/customer/create', data);
      if (response !== null) {
        return response.data;
      } else {
        throw new Error('http.post returned null-like value.');
      }
    } catch (error) {
      // 可以在此處處理錯誤或回傳預設值
      console.error('An error occurred while creating appointment demand:', error);
      throw error;
    }
  }


}

export default new QueryConsultantService();

export interface AddFavoriteConsultantItem {
  agentNo    : string;
  createdTime: string;
}
